@@ -691,7 +691,6 @@ generate_header_method_protos (FILE *out, Structure *structure)
 				fwrite (typeName, sizeof (gchar), strlen (typeName), privateHeader);
 				fputc (';', privateHeader);
 				fputc ('\n', privateHeader);
-
 			}
 			generate_header_method_proto (privateHeader, method);
 		} else {
@@ -1017,14 +1016,14 @@ generate_source_includes (FILE *out, Structure *structure)
 	upperCamel = g_strconcat (structure->nameSpace, structure->name, NULL);
 	lowerTrain = get_lower_train_from_upper_camel (upperCamel);
 	g_free (upperCamel);
-	fwrite ("#include <libical-glib/", sizeof (gchar), strlen ("#include <libical-glib/"), out);
+	fwrite ("#include \"", sizeof (gchar), strlen ("#include \""), out);
 	fwrite (lowerTrain, sizeof (gchar), strlen (lowerTrain), out);
-	fwrite (".h>\n", sizeof (gchar), strlen (".h>\n"), out);
+	fwrite (".h\"\n", sizeof (gchar), strlen (".h\"\n"), out);
 	g_free (lowerTrain);
 
-	fwrite ("#include <libical-glib/", sizeof (gchar), strlen ("#include <libical-glib/"), out);
+	fwrite ("#include \"", sizeof (gchar), strlen ("#include \""), out);
 	fwrite (PRIVATE_HEADER, sizeof (gchar), strlen (PRIVATE_HEADER), out);
-	fwrite (">\n", sizeof (gchar), strlen (">\n"), out);
+	fwrite ("\"\n", sizeof (gchar), strlen ("\"\n"), out);
 		
 	for (g_hash_table_iter_init (&iter_table, structure->dependencies); g_hash_table_iter_next (&iter_table, &key, &value);) {
 		typeName = (gchar *)key;
@@ -1046,9 +1045,9 @@ generate_source_includes (FILE *out, Structure *structure)
 	
 	for (g_hash_table_iter_init (&iter_table, includeNames); g_hash_table_iter_next (&iter_table, &key, &value);) {
 		includeName = (gchar *)key;
-		fwrite ("#include <libical-glib/", sizeof (gchar), strlen ("#include <libical-glib/"), out);
+		fwrite ("#include \"", sizeof (gchar), strlen ("#include \""), out);
 		fwrite (includeName, sizeof (gchar), strlen (includeName), out);
-		fwrite (".h>\n", sizeof (gchar), strlen (".h>\n"), out);
+		fwrite (".h\"\n", sizeof (gchar), strlen (".h\"\n"), out);
 	}
 
 	fputc ('\n', out);
