@@ -21,17 +21,17 @@
 #include <config.h>
 #endif
 
-#include <libical-glib/i-cal-component.h>
-#include <libical-glib/libical-glib-private.h>
-#include <libical-glib/i-cal-duration-type.h>
-#include <libical-glib/i-cal-comp-iter.h>
-#include <libical-glib/i-cal-property.h>
-#include <libical-glib/i-cal-derived-value.h>
-#include <libical-glib/i-cal-timetype.h>
-#include <libical-glib/i-cal-enums.h>
-#include <libical-glib/i-cal-time-span.h>
-#include <libical-glib/i-cal-timezone.h>
-#include <libical-glib/i-cal-derived-property.h>
+#include "i-cal-component.h"
+#include "libical-glib-private.h"
+#include "i-cal-duration-type.h"
+#include "i-cal-comp-iter.h"
+#include "i-cal-property.h"
+#include "i-cal-derived-value.h"
+#include "i-cal-timetype.h"
+#include "i-cal-enums.h"
+#include "i-cal-time-span.h"
+#include "i-cal-timezone.h"
+#include "i-cal-derived-property.h"
 
 G_DEFINE_TYPE (ICalComponent, i_cal_component, I_CAL_TYPE_OBJECT)
 
