@@ -21,9 +21,9 @@
 #include <config.h>
 #endif
 
-#include <libical-glib/i-cal-derived-parameter.h>
-#include <libical-glib/libical-glib-private.h>
-#include <libical-glib/i-cal-parameter.h>
+#include "i-cal-derived-parameter.h"
+#include "libical-glib-private.h"
+#include "i-cal-parameter.h"
 
 /**
  * i_cal_parameter_new_actionparam:
