@@ -21,18 +21,18 @@
 #include <config.h>
 #endif
 
-#include <libical-glib/i-cal-derived-value.h>
-#include <libical-glib/libical-glib-private.h>
-#include <libical-glib/i-cal-duration-type.h>
-#include <libical-glib/i-cal-datetimeperiod-type.h>
-#include <libical-glib/i-cal-recurrence-type.h>
-#include <libical-glib/i-cal-period-type.h>
-#include <libical-glib/i-cal-timetype.h>
-#include <libical-glib/i-cal-geo-type.h>
-#include <libical-glib/i-cal-trigger-type.h>
-#include <libical-glib/i-cal-value.h>
-#include <libical-glib/i-cal-reqstat-type.h>
-#include <libical-glib/i-cal-attach.h>
+#include "i-cal-derived-value.h"
+#include "libical-glib-private.h"
+#include "i-cal-duration-type.h"
+#include "i-cal-datetimeperiod-type.h"
+#include "i-cal-recurrence-type.h"
+#include "i-cal-period-type.h"
+#include "i-cal-timetype.h"
+#include "i-cal-geo-type.h"
+#include "i-cal-trigger-type.h"
+#include "i-cal-value.h"
+#include "i-cal-reqstat-type.h"
+#include "i-cal-attach.h"
 
 /**
  * i_cal_value_set_x:
