@@ -21,9 +21,9 @@
 #include <config.h>
 #endif
 
-#include <libical-glib/i-cal-mime.h>
-#include <libical-glib/libical-glib-private.h>
-#include <libical-glib/i-cal-component.h>
+#include "i-cal-mime.h"
+#include "libical-glib-private.h"
+#include "i-cal-component.h"
 
 /**
  * i_cal_mime_parse:
