@@ -77,8 +77,6 @@ typedef enum {
 	I_CAL_PARSER_IN_PROGRESS = ICALPARSER_IN_PROGRESS
 } ICalParserState;
 
-ICalParser *	i_cal_parser_new_full		(icalparser *native,
-						 GObject *owner);
 GType 		i_cal_parser_get_type		(void);
 ICalParser *	i_cal_parser_new		(void);
 ICalComponent *	i_cal_parser_add_line		(ICalParser *parser,
