@@ -21,13 +21,13 @@
 #include <config.h>
 #endif
 
-#include <libical-glib/i-cal-property.h>
-#include <libical-glib/libical-glib-private.h>
-#include <libical-glib/i-cal-value.h>
-#include <libical-glib/i-cal-parameter.h>
-#include <libical-glib/i-cal-derived-value.h>
-#include <libical-glib/i-cal-derived-property.h>
-#include <libical-glib/i-cal-derived-parameter.h>
+#include "i-cal-property.h"
+#include "libical-glib-private.h"
+#include "i-cal-value.h"
+#include "i-cal-parameter.h"
+#include "i-cal-derived-value.h"
+#include "i-cal-derived-property.h"
+#include "i-cal-derived-parameter.h"
 
 G_DEFINE_TYPE (ICalProperty, i_cal_property, I_CAL_TYPE_OBJECT)
 
