@@ -70,9 +70,6 @@ struct _ICalRecurIteratorClass {
 typedef struct _ICalTimetype ICalTimetype;
 typedef struct _ICalRecurrenceType ICalRecurrenceType;
 
-ICalRecurIterator *
-		i_cal_recur_iterator_new_full	(icalrecur_iterator *native,
-						 GObject *owner);
 GType 		i_cal_recur_iterator_get_type	(void);
 ICalRecurIterator *
 		i_cal_recur_iterator_new	(ICalRecurrenceType *rule,
