@@ -21,9 +21,9 @@
 #include <config.h>
 #endif
 
-#include <libical-glib/i-cal-recurrence-type.h>
-#include <libical-glib/libical-glib-private.h>
-#include <libical-glib/i-cal-timetype.h>
+#include "i-cal-recurrence-type.h"
+#include "libical-glib-private.h"
+#include "i-cal-timetype.h"
 
 G_DEFINE_TYPE (ICalRecurrenceType, i_cal_recurrence_type, I_CAL_TYPE_OBJECT)
 
