@@ -91,11 +91,7 @@ typedef enum {
 	I_CAL_SATURDAY_WEEKDAY = ICAL_SATURDAY_WEEKDAY
 } ICalRecurrenceTypeWeekday;
 
-ICalRecurrenceType *
-		i_cal_recurrence_type_new_full	(struct icalrecurrencetype native);
 GType 		i_cal_recurrence_type_get_type	(void);
-struct icalrecurrencetype 
-		i_cal_recurrence_type_new	(void);
 void		i_cal_recurrence_type_clear	(ICalRecurrenceType *r);
 ICalRecurrenceTypeWeekday 
 		i_cal_recurrence_type_day_day_of_week
