@@ -21,11 +21,11 @@
 #include <config.h>
 #endif
 
-#include <libical-glib/i-cal-time.h>
-#include <libical-glib/libical-glib-private.h>
-#include <libical-glib/i-cal-time-span.h>
-#include <libical-glib/i-cal-timetype.h>
-#include <libical-glib/i-cal-timezone.h>
+#include "i-cal-time.h"
+#include "libical-glib-private.h"
+#include "i-cal-time-span.h"
+#include "i-cal-timetype.h"
+#include "i-cal-timezone.h"
 
 /**
  * i_cal_time_null_time:
