@@ -69,10 +69,7 @@ struct _ICalTimetypeClass {
 
 typedef struct _ICalTimezone ICalTimezone;
 
-ICalTimetype *	i_cal_timetype_new_full		(struct icaltimetype native);
 GType 		i_cal_timetype_get_type		(void);
-struct icaltimetype 
-		i_cal_timetype_new_default	(void);
 ICalTimetype *	i_cal_timetype_new		(void);
 gint 		i_cal_timetype_get_year		(ICalTimetype *timetype);
 void		i_cal_timetype_set_year		(ICalTimetype *timetype,
