@@ -72,12 +72,7 @@ struct _ICalTimezonePhaseClass {
 typedef struct _ICalTimetype ICalTimetype;
 typedef struct _ICalDatetimeperiodType ICalDatetimeperiodType;
 
-ICalTimezonePhase *
-		i_cal_timezone_phase_new_full	(struct icaltimezonephase native);
 GType 		i_cal_timezone_phase_get_type	(void);
-struct icaltimezonephase 
-		i_cal_timezone_phase_new_default
-						(void);
 const gchar *	i_cal_timezone_phase_get_tzname	(ICalTimezonePhase *phase);
 gint 		i_cal_timezone_phase_is_stdandard
 						(ICalTimezonePhase *phase);
