@@ -21,11 +21,11 @@
 #include <config.h>
 #endif
 
-#include <libical-glib/i-cal-timezone.h>
-#include <libical-glib/libical-glib-private.h>
-#include <libical-glib/i-cal-component.h>
-#include <libical-glib/i-cal-array.h>
-#include <libical-glib/i-cal-timetype.h>
+#include "i-cal-timezone.h"
+#include "libical-glib-private.h"
+#include "i-cal-component.h"
+#include "i-cal-array.h"
+#include "i-cal-timetype.h"
 
 G_DEFINE_TYPE (ICalTimezone, i_cal_timezone, I_CAL_TYPE_OBJECT)
 
