@@ -70,11 +70,7 @@ struct _ICalTimezonetypeClass {
 
 typedef struct _ICalTimetype ICalTimetype;
 
-ICalTimezonetype *
-		i_cal_timezonetype_new_full	(struct icaltimezonetype native);
 GType 		i_cal_timezonetype_get_type	(void);
-struct icaltimezonetype 
-		i_cal_timezonetype_new_default	(void);
 const gchar *	i_cal_timezonetype_get_tzid	(ICalTimezonetype *timezonetype);
 const gchar *	i_cal_timezonetype_get_tzurl	(ICalTimezonetype *timezonetype);
 ICalTimetype *	i_cal_timezonetype_get_last_mod	(ICalTimezonetype *timezonetype);
