@@ -21,8 +21,8 @@
 #include <config.h>
 #endif
 
-#include <libical-glib/i-cal-unknowntokenhandling.h>
-#include <libical-glib/libical-glib-private.h>
+#include "i-cal-unknowntokenhandling.h"
+#include "libical-glib-private.h"
 
 /**
  * i_cal_get_unknown_token_handling_setting:
