@@ -70,8 +70,6 @@ struct _ICalValueClass {
 	ICalObjectClass parent;
 };
 
-ICalValue *	i_cal_value_new_full		(icalvalue *native,
-						 GObject *owner);
 GType 		i_cal_value_get_type		(void);
 ICalValue *	i_cal_value_new			(ICalValueKind kind);
 ICalValue *	i_cal_value_new_clone		(const ICalValue *value);
